@@ -301,12 +301,6 @@ pub struct Contract {
     pub contractBytes: Vec<u8>,
 }
 
-#[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
-pub struct Authorization {
-    pub account: ID,
-    pub authorize: bool,
-}
-
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
 pub struct Data {
     pub channelID: ID,
